@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20120831';
+our $VERSION = '0.20120928';
 
-# Table last modified: 2012-08-31
+# Table last modified: 2012-09-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -67,7 +67,7 @@ our %ZIP_TABLE = (
     '061' => '(?:(?:1(?:49[236-8]|19[2356]|39[2356])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292))',
     '062' => '(?:8(?:6(?:55|86|0[1-357-9]|3[0135]|2[24]|4[12]|1[0278]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:58|0[17]|[18][05])|6(?:41|0[1-36-8]|1[12])))',
-    '064' => '(?:8(?:5(?:1[0-2569]|6[0-7]|2[0-68]|7[0157]|5[0-24-8]|3[0235-7]|0[1-3569]|8[14-79]|4[0-6])|6(?:86|2[0-2489]|0[159]|1[01]|4[124589]|3[039])|798))',
+    '064' => '(?:8(?:5(?:1[0-2569]|6[0-7]|2[0-68]|7[0157]|5[0-24-8]|3[0235-7]|0[1-3569]|8[14-79]|4[0-6])|6(?:86|2[0-2489]|0[159]|1[01]|4[12458]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:86|3[39]|0[19]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
@@ -104,21 +104,21 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|22|77|8[0-35]|1[125689])|79[58]))',
+    '101' => '(?:8(?:3(?:3[135]|0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:10|0[1-4])|101))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|55|0[1258]|7[07]|8[58]|1[0-2])|3(?:01|22|1[0-3]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
+    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|8[0-578]|3[02-5]|1[0-28]|6[02-478]|5[0-2457])|5(?:4[018]|6[02369]|3[138]|8[0235]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[013-5]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
-    '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|(?:60|71)1))',
+    '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-26]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
     '120' => '(?:8(?:5(?:44|81|7[057]|0[178]|1[02]|2[068]|3[0469]|5[03568])|60[12]))',
     '121' => '(?:8(?:5(?:33|40|0[245]|2[0-4]|8[58]|5[05]|1[01])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|0[2-6]|7[0-36]|8[0136-8]|4[0-46-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[02-46-8]|0[2-6]|7[0-36]|8[0136-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[14]|6[01])))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:22|33|55|8[58]|0[126]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:1[015]|3[13]|4[47]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
+    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:1[015]|4[47]|3[013]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[013])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|5[35]|6[56])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
@@ -219,7 +219,7 @@ our %ZIP_TABLE = (
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
     '238' => '(?:(?:8(?:5(?:33|41|8[058]|2[02]|6[57]|5[08]|1[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|8[58])|68[68]))',
-    '240' => '(?:(?:85(?:[02]1|[45]0|15)|019[2-8]))',
+    '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
     '242' => '(?:8(?:5(?:[07]7|[58]5)|6(?:01|10)))',
     '243' => '(?:(?:0(?:4(?:60|9[2-8]|8[3-689])|19[23578]|29[278]|392)|8(?:5(?:21|33|88|5[015]|7[17]|1[01]|0[15])|60[14])))',
@@ -303,11 +303,11 @@ our %ZIP_TABLE = (
     '327' => '(?:(?:8(?:5(?:11|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|5[0568]|8[568]|0[1-5])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:1(?:19[3-68]|39[2-5]|292|493)|0(?:59[568]|49[28]|69[26]|195)|2(?:79[237]|19[23]|99[23]|292)|4(?:49[23]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|6[4-6]|3[156]|2[35]|7[57]|1[0-2]|0[1-37-9]|8[0-3568])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:01|30|77|1[01])|0(?:11|45|77|88)|7(?:15|9[67])|1(?:09|11)|850)|8(?:5(?:47|8[015]|0[3568]|3[238]|1[0189]|2[29]|7[129]|5[01]|6[56])|6(?:01|69|8[68]))))',
+    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|6[4-6]|3[156]|2[35]|7[57]|1[0-2]|0[1-37-9]|8[0-3568])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:01|30|77|1[01])|7(?:15|9[67])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|8[015]|0[3568]|3[238]|1[0189]|2[29]|7[129]|5[01]|6[56])|6(?:01|69|8[68]))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|1[13]|5[02]|6[07]|3[237]|8[06-8])|6(?:33|58|8[67]))|9(?:5(?:[1-35]0|77)|624)))',
     '332' => '(?:8(?:5(?:21|48|77|85|5[568]|0[12]|1[0-2])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
-    '334' => '(?:85[01]1)',
+    '334' => '(?:8501)',
     '335' => '(?:8(?:5(?:22|33|55|8[58]|1[01]|0[1-35])|6(?:55|66)|792))',
     '336' => '(?:8(?:5(?:40|6[14]|1[25]|0[568]|8[167]|5[58]|2[0256])|6(?:01|36|55)|760))',
     '337' => '(?:85(?:32|70|86|0[27]))',
@@ -372,7 +372,7 @@ our %ZIP_TABLE = (
     '396' => '(?:(?:8(?:5(?:01|85|5[058]|1[01])|6(?:09|82|1[17]))|0(?:198|293)))',
     '397' => '(?:(?:8(?:5(?:55|67|71|8[58])|60[29])|0[23]92))',
     '398' => '(?:8(?:6(?:86|0[12])|501))',
-    '399' => '(?:(?:8(?:7(?:44|60|2[0-258]|5[0145]|1[0-2]|3[0389]|0[1-37])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[4-8]|8[13-9]|9[2-578]|7[0-3568])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[56]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|7192))',
+    '399' => '(?:(?:8(?:7(?:44|60|2[0-258]|5[0145]|1[0-2]|3[0389]|0[1-37])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[4-8]|8[13-9]|9[2-578]|7[0-3568])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[56]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]))',
     '400' => '(?:(?:8(?:5(?:8[568]|0[1568]|1[0-25]|4[03-5]|7[01578]|2[15]|5[05689]|6[56]|3[1356])|6(?:01|10|33|66))|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
     '401' => '(?:(?:0(?:3(?:80|9[5-8])|59[257]|292)|8[56]01))',
     '402' => '(?:85(?:01|55))',
@@ -432,12 +432,12 @@ our %ZIP_TABLE = (
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:11|22|40))',
     '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|0[1-3689]|3[0-35-8]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|0[1-35-8]|1[125-7]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-69]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|1[0-68]|4[0135]|7[04578]|0[13-9]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
-    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[125])|6(?:66|80|4[015]|3[019]|0[2358]|5[01458]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
+    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[125])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
-    '464' => '(?:8(?:5(?:85|5[058]|2[0-25]|4[035-7]|1[12]|6[0167]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
+    '464' => '(?:8(?:5(?:85|5[058]|4[035-7]|1[12]|6[0167]|2[0-2]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])))',
-    '466' => '(?:8(?:5(?:40|3[39]|6[057]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:73|6[06]|5[05-7]|3[035])|7(?:11|0[17])))',
+    '466' => '(?:8(?:5(?:40|6[05-7]|3[39]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:73|6[06]|5[05-7]|3[035])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|2[0-25]|5[58]|1[01])|6(?:51|86|2[26]|1[015]|0[1-3]|3[039])))',
     '468' => '(?:8(?:5(?:2[02]|1[0-4]|8[58]|0[1-7]|3[1-467])|626))',
     '469' => '(?:879[3467])',
@@ -448,10 +448,10 @@ our %ZIP_TABLE = (
     '474' => '(?:8(?:5(?:22|35|43|8[01458]|5[0578]|1[01]|0[1-35])|6(?:[05]1|42|66|8[68]|1[01])|7(?:10|66|77|0[17])))',
     '475' => '(?:8(?:5(?:41|60|74|99|5[057]|2[28]|8[58]|0[12]|1[01])|6(?:[01]1|55|86|6[68])))',
     '476' => '(?:8(?:5(?:[67]7|33|0[13]|8[58]|1[01])|6(?:[68]6|01)))',
-    '477' => '(?:85(?:21|38))',
+    '477' => '(?:8521)',
     '478' => '(?:8(?:5(?:55|0[1-5])|6(?:01|4[01])))',
     '479' => '(?:8(?:5(?:01|55|77|1[018]|8[5689])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
-    '480' => '(?:(?:0(?:2(?:8[128]|9[1246])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-9])|298)))',
+    '480' => '(?:(?:0(?:2(?:8[128]|9[1246])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-8])|298)))',
     '481' => '(?:8(?:5(?:26|88|4[03]|5[058]|1[0135]|0[1-58]|3[1359])|6(?:[08]1|15|78)))',
     '482' => '(?:8(?:5(?:01|55|1[01])|6(?:86|5[12])))',
     '483' => '(?:8(?:5(?:55|0[2357])|70[14]))',
@@ -467,7 +467,7 @@ our %ZIP_TABLE = (
     '494' => '(?:8(?:5(?:1[168]|0[1257])|6(?:[01]1|86)))',
     '495' => '(?:8(?:5(?:31|0[15]|1[017])|601))',
     '496' => '(?:8(?:5(?:[78]5|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
-    '497' => '(?:8(?:5(?:4[158]|0[1258]|3[013]|1[0-2]|2[0278])|601))',
+    '497' => '(?:8(?:5(?:4[158]|0[1258]|3[0138]|1[0-2]|2[0278])|601))',
     '498' => '(?:850[1-35])',
     '500' => '(?:8(?:6(?:1[056]|4[0568]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|5[0157]|3[05-9]|6[06-8])|5(?:88|1[0358]|4[045]|0[124578]|7[07]|6[015-7]|2[1-5]|3[035]|5[024-8])|7(?:65|5[0-35]|4[0-38]|3[0-47]|1[015-8]|0[1-378]|2[0-257-9])))',
     '501' => '(?:(?:0(?:49[2-8]|69[2-7]|29[2-6]|[135]92|79[78])|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235-7])|4(?:29[278]|19[23]|59[25])|1(?:19[2-68]|[235]92)|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:8(?:2(?:6[26]|8[128]|1[0-35-7]|5[12]|4[157]|7[08]|2[267]|0[1-69]|3[049])|5(?:01|44|2[1-3]|6[05-7]|5[1568]|7[45]|8[02368]|3[15]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
+    '530' => '(?:8(?:2(?:6[26]|8[128]|1[0-35-8]|5[12]|4[157]|7[08]|2[267]|0[1-69]|3[049])|5(?:01|44|2[1-3]|6[05-7]|5[1568]|7[45]|8[02368]|3[15]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
     '531' => '(?:8(?:5(?:67|0[1-3]|5[58]|1[01])|787))',
     '532' => '(?:8(?:5(?:35|60|77|2[045]|8[58]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:66|4[0147]|2[1267]|5[01589]|0[158]|3[03-5]|7[01578]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
-    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|8[15-79]|7[1568]|4[0-35-8]|0[1-35689]|1[126-8]|6[368]|3[014578])|6666))',
+    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|7[1568]|4[0-35-7]|8[1579]|0[1-35689]|1[16-8]|6[368]|3[014578])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
@@ -633,7 +633,7 @@ our %ZIP_TABLE = (
     '669' => '(?:(?:3(?:39[24-6]|19[28]|69[23]|892)|5(?:19[2378]|39[258]|292)|6(?:[2578]92|19[25])|2(?:[12]92|397)|159[25]|4[13]92))',
     '670' => '(?:8(?:5(?:43|3[03]|7[057]|8[058]|6[67]|5[0458]|2[024]|1[017]|0[1256])|6(?:7[057]|5[25]|6[068]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:59[2358]|19[238]|28[08])|419[23]|0295))',
-    '672' => '(?:8(?:5(?:01|67|85|5[058])|6(?:55|66|77)))',
+    '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:11|58|85)|6[68]6)|1(?:49[3-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:[58]5|01)|686))',
     '675' => '(?:(?:8(?:5(?:01|22|33|66|77|88|1[019]|5[58])|68[68])|01(?:9[2-468]|8[0-68])|1(?:3(?:80|95)|192|297)|239[358]))',
@@ -663,7 +663,7 @@ our %ZIP_TABLE = (
     '702' => '(?:8(?:5(?:1[0-25]|0[125-8])|60[1-35-79]))',
     '703' => '(?:8(?:5(?:44|6[06]|3[03]|0[1258]|[58][058]|2[02]|7[03-5]|1[016])|6(?:55|86)|750))',
     '704' => '(?:85(?:10|55|88|0[12]))',
-    '705' => '(?:8(?:5(?:10|0[127]|[58][58]|7[57])|6(?:0[239]|1[45])))',
+    '705' => '(?:8(?:5(?:10|0[127]|[58][58]|7[57])|6(?:0[23]|1[45])))',
     '706' => '(?:8(?:5(?:01|55|3[13]|1[01])|65[15]))',
     '707' => '(?:85(?:85|0[12]))',
     '708' => '(?:(?:8(?:5(?:20|1[0-25-9]|0[1-35-79])|6(?:09|5[2-47]))|1(?:19[38]|39[23])|0(?:39[23]|698)))',
@@ -694,7 +694,7 @@ our %ZIP_TABLE = (
     '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
     '735' => '(?:8(?:5(?:01|10|55|77|88)|6(?:70|86)))',
     '736' => '(?:8(?:5(?:55|0[124-9])|60[12]))',
-    '737' => '(?:(?:8(?:5(?:20|54|77|0[1-9]|1[0236-8])|6(?:09|11|86|5[0-3]))|2(?:29[235]|19[35]|39[23])|01(?:82|9[23578])))',
+    '737' => '(?:(?:8(?:5(?:20|41|54|77|0[1-9]|1[0236-8])|6(?:09|11|86|5[0-3]))|2(?:29[235]|19[35]|39[23])|01(?:82|9[23578])))',
     '738' => '(?:(?:8(?:5(?:12|0[1-9])|60[1-3])|0292))',
     '739' => '(?:(?:8(?:5(?:01|30|1[1-4]|2[124-9])|6(?:0[1-3]|1[56]))|0(?:4(?:81|9[24-7])|69[23568]|19[238]|59[25])|1(?:79[2-4]|19[25]|29[23])|2(?:49[248]|69[235])))',
     '740' => '(?:8(?:5(?:[58]5|01|67|3[35]|1[016])|6(?:11|39|86|4[26])))',
@@ -746,7 +746,7 @@ our %ZIP_TABLE = (
     '787' => '(?:(?:0[38]92|8501))',
     '788' => '(?:8(?:501|686))',
     '789' => '(?:(?:1(?:[29]92|795)|0392))',
-    '790' => '(?:8(?:5(?:4[0-356]|7[013-578]|9[05]|6[015-7]|2[04589]|1[0-4679]|3[0-79]|5[1-7]|8[013-9]|0[1-3589])|6(?:32|6[015-7]|7[078]|8[68]|5[0-35689])|7(?:87|9[135-8])))',
+    '790' => '(?:8(?:5(?:4[0-356]|7[013-578]|9[05]|6[015-7]|2[04589]|1[0-4679]|3[0-79]|5[1-7]|8[013-9]|0[1-3589])|6(?:32|7[78]|6[015-7]|8[68]|5[0-35689])|7(?:87|9[135-8])))',
     '791' => '(?:(?:8(?:5(?:51|2[3-578]|1[0-36-8]|3[01568]|0[125-8])|6(?:0[34]|7[1257]))|0(?:2(?:8[018]|9[257])|3(?:85|9[23578])|59[34])|3(?:19[2-8]|29[235]|[35]92)|(?:45|1[17])92|219[135]))',
     '792' => '(?:8(?:5(?:43|67|1[018]|8[0568]|5[05]|2[01]|0[15])|6(?:14|70|86)))',
     '793' => '(?:8(?:5(?:[58]5|0[19]|1[05])|601))',
